DECLARE FUNCTION ConvertDoublePrecisionToDollars# (a#)

'foreign tax credit
'This program helps fill out form 1116 of the USA Internal Revenue Service,
'the foreign tax credit.

'This is version 3 of this program, for tax year 2000 and maybe later.
'For tax year 2000, lines 31 and 32 became lines 31 to 33. If you are
'doing tax year 1999 or earlier, ignore what this program says about
'lines 31-33 and fill out lines 31-32 manually.

'Version 2 of this program is for tax year 1999.
'For tax year 1999, the boxes and columns were relettered, so if you
'are doing tax year 1998 or earlier, what this program calls column x
'is really column v; what this program calls line i is line j, etc.

'Version 1 of this program is for tax years 1998 and previous.

'This program was written and tested with Qbasic from MS DOS 5.00,
'running under DR DOS 6.0, on a 386SX/16 with 2M of RAM.  I think
'this will work with any version of Qbasic, including the Windows 95
'version of Qbasic, and I think you can use any version of DOS
'or Windows, and any computer that will run DOS or Windows.
'Or maybe it requires DOS 3 or later. I think this program will
'also run with PowerBasic 3, and it might run with QuickBasic.

'This program was originally written by Kenneth Howlett in March 1997;
'and last updated in February 2001.
'It is free and you can do anything you want with it.

'I wrote this program by following the directions for form 1116.  If I
'misunderstood the directions, then the program will be wrong, and so
'will your tax return, and so will my tax return, and we will both go
'to jail.  If you are worried about the possibility of becoming my
'cellmate, then hire an accountant instead of using this program.
'In other words, I do NOT guarantee that this program fills out form
'1116 correctly.

'I own shares in the T Rowe Price International Stock Fund. This is
'my only source of foreign income, and the taxes paid by the fund are
'the only foreign taxes I pay. This program makes some assumptions
'which are true for me, but if your situation is different, then this
'program might not work correctly for you. This program might not work
'if you have other forms of foreign income or foreign taxes; if you
'have more than one foreign mutual fund; or if your statements of
'foreign income and foreign taxes are not in the format used by
'T Rowe Price.

'Before you begin you need to know how much income came from, and how
'much taxes were paid to, each country.  You should have a list saying
'Argentina, .70% of income, .13% of taxes; Australia, 1.78% of income,
'.98% of taxes; etc.

'If your mutual fund is well diversified, it will have invested in
'many different countries, and will probably have paid taxes to
'many different countries.  You can only list three countries on
'each form 1116, so you will have to fill out several copies.  Half
'the stuff is the same on every copy.  So we will save some writing
'by first filling out the stuff that is the same, then making copies
'of the partially completed form 1116, and then filling out the rest.

'Take a blank form 1116.  Fill in your name, social security number,
'check the box beside Passive Income, and write USA where it says
'resident of.  If Passive Income and USA are wrong for you, this
'program may not work right. Write "mutual fund distributions" on
'the dotted line beside/under item 1, part I.  Fill out columns A,
'B, and C of lines 2, 3a, 3b, 3c, 3e, 4a, 4b, and 5.  This program
'assumes that these lines will be the same for all countries, and
'that lines 2, 4a, 4b, and 5 all are $0.00.  If that is not
'true, this program will not work right.  Now change the next
'two lines of the program to the numbers you wrote on form 1116
'in lines 3c and 3e:
Line3c# = 865849252.76#
Line3e# = 43214314.65#

'You should end the numbers with #; this makes the calculations more
'accurate.

'For form 1116, part II, lines A, B, and C, column o, write
'"12-31-96 form 1099", but use the correct year if you are not
'doing your 1996 taxes. Use column m for tax year 1998 and earlier.
'Check box m, for taxes paid.

'Now make copies of your partially completed form 1116.
'You do not need to copy the back side.

'Now go to parts III and IV of the original and fill out lines 10, 12,
'15, 17, 19, and 31.  Enter your results into the program on the next
'six lines:
Line10# = 0#
Line12# = 0#
Line15# = 0#
Line17# = 58629843.56#
Line19# = 58329483.34#
Line32# = 0#
'If you are doing tax year 1999 or earlier, Line32# is line 31.

'Get the form 1099-DIV for the mutual fund and get the numbers from
'box 1 (ordinary dividends); and box 6 (foreign tax paid).  Enter these
'numbers into the program on the next two lines:
Form1099Box1# = 8435943.45#
Form1099Box6# = 8438591.45#
'form 1099-DIV changed between 1997 and 1998. For doing 1997 or earlier,
'use box 1b (ordinary dividends) for Form1099Box1#,
'and use box 3 (foreign tax paid) for Form1099Box6#

'Some comments on the last part: T Rowe Price advises shareholders
'to use the number in box 1 (ordinary dividends) for foreign income;
'and says nothing about including box 2a (total capital gain distribution).
'But the IRS instructions for form 1116 say that capital gains should
'be included in foreign income, and you have to fill out a foreign
'schedule D to calculate how much capital gains to include with
'foreign income. If you use the T Rowe Price method, you can skip
'the foreign schedule D, so the T Rowe Price method is easier.
'The amount of tax you owe might be the same with both methods.
'or you might pay more tax if you use the T Rowe Price method. I do not
'think you will ever pay less tax if you use the T Rowe Price method.
'I do not think the IRS will care if you use the T Rowe Price method,
'because it will not save you any money, it will only save you time.
'So I suggest that you try the T Rowe Price method first. Start the program,
'do not actually fill the form out because this is a test run, and
'when it says what percent for this country, give the total percent
'for all foreign countries; when it asks if you want to do another country,
'press q for a quick total; if your credit so far is equal to the total
'foreign tax paid from form 1099-DIV, then the two methods will give
'you the same credit; if your credit so far is less than the total
'foreign tax paid, then you will probably get a bigger credit if you
'use the IRS method. (Then press escape to quit).


'OK, you are ready to run the program.  Write the name of the first
'country on your list onto form 1116, part I, line i.  The
'program will ask you what percent of income came from this country,
'and what percent of tax was paid to this country.  Then it will tell
'you what to write on the next line and pause.  Write the number and
'then press any key, and then it will tell you the next line.  The
'program does most of the calculations while it waits for you to write
'the last number, which creates the illusion of blinding speed.

'When you are finished with a country, you will have a choice of doing
'another country or doing the totals.  If you want to do the totals
'but the program starts another country, just press enter when the
'program asks what percentage and keep going until you get back to
'the totals prompt.  If you want to do another country but the program
'does the totals, just keep going; at the end you will have the option
'of doing another country.  Note that you can not save your work.
'Once you start, you have to keep going until you finish.  You can quit
'anytime by pressing [ESCAPE], but once you stop the program, you have
'to go back to the beginning and start again.

'If you received income from a country but paid no tax to that country,
'list the country anyway; it might increase the size of your credit,
'or it might have no effect. Or you could leave that country until
'last, and then press q for a quick total; if your credit so far is
'equal to the total foreign tax paid from form 1099-DIV, then skip
'that country; you can not increase the size of your credit because
'you already have the maximum credit.


' Press F5 to begin.









'press escape to abort
KEY 15, CHR$(0) + CHR$(1): ON KEY(15) GOSUB SomeonePressedEscape: KEY(15) ON
KEY 16, CHR$(32) + CHR$(1): ON KEY(16) GOSUB SomeonePressedEscape: KEY(16) ON
KEY 17, CHR$(64) + CHR$(1): ON KEY(17) GOSUB SomeonePressedEscape: KEY(17) ON
KEY 18, CHR$(96) + CHR$(1): ON KEY(18) GOSUB SomeonePressedEscape: KEY(18) ON


TotalForLine1# = 0#
TotalForLine6# = 0#
TotalForLine8# = 0#

CLS


NextCountry:
PRINT
PRINT
PRINT "write the name of the country on line i in part I"
PRINT

DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "what percent of the income came from this country?"
PRINT "(enter 10.16% as 10.16; enter .37% as .37; etc)"
PRINT
INPUT a#

PRINT
PRINT "what percent of the tax was paid to this country?"
PRINT "(enter 10.16% as 10.16; enter .37% as .37; etc)"
PRINT
INPUT PercentageOfTaxPaidToThisCountry#

a# = a# * Form1099Box1# / 100#
TotalForLine1# = TotalForLine1# + a#
PRINT
PRINT "line 1 and line 3d are:  ";
PRINT ConvertDoublePrecisionToDollars#(a#)
PRINT

a# = a# / Line3e#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 3f is:  ";
PRINT a#
PRINT

a# = a# * Line3c#
TotalForLine6# = TotalForLine6# + a#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "lines 3g and 6 are:  ";
PRINT ConvertDoublePrecisionToDollars#(a#)
PRINT

a# = Form1099Box6# * PercentageOfTaxPaidToThisCountry# / 100#
TotalForLine8# = TotalForLine8# + a#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "columns t and x in part II are:  ";
PRINT ConvertDoublePrecisionToDollars#(a#)
PRINT

WhichRoutineNext:
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT
PRINT
PRINT "add up the totals or go on to the next country?"
PRINT "press t for the totals, press [ESCAPE] to quit,"
PRINT "press q for a quick summary of how large your credit is so far,"
PRINT "press any other key to do another country"
PRINT
PRINT
PRINT
GetKeyCode:
a$ = INKEY$
a$ = LCASE$(a$)
IF a$ = "q" THEN GOTO QuickSubtotal
IF a$ = "t" THEN GOTO AddUpTotals
IF a$ = "" THEN GOTO GetKeyCode
GOTO NextCountry


AddUpTotals:
PRINT
PRINT "total for line 1 is:  ";
PRINT ConvertDoublePrecisionToDollars#(TotalForLine1#)
PRINT

DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "total for line 6 is:  ";
PRINT ConvertDoublePrecisionToDollars#(TotalForLine6#)
PRINT

Lines7and14# = TotalForLine1# - TotalForLine6#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 7 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Lines7and14#)
PRINT

DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 8 is:  ";
PRINT ConvertDoublePrecisionToDollars#(TotalForLine8#)
PRINT

DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 9 is:  ";
PRINT ConvertDoublePrecisionToDollars#(TotalForLine8#)
PRINT

Line11# = TotalForLine8# + Line10#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 11 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line11#)
PRINT

Line13# = Line11# - Line12#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 13 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line13#)
PRINT

DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 14 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Lines7and14#)
PRINT

Line16# = Lines7and14# + Line15#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 16 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line16#)
PRINT

Line18# = Line16# / Line17#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 18 is:  ";
PRINT Line18#
PRINT

Line20# = Line18# * Line19#
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 20 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line20#)
PRINT

IF Line13# > Line20# THEN
  CarryOver# = Line13# - Line20#
  Line30# = Line20#
ELSE
  Line30# = Line13#
  CarryOver# = 0#
END IF
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "lines 21, 22, and 30 are:  ";
PRINT ConvertDoublePrecisionToDollars#(Line30#)
PRINT

IF Line19# < Line30# THEN
  Line31# = Line19#
ELSE
  Line31# = Line30#
END IF
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 31 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line31#)
PRINT

Line33# = Line31# - Line32#
IF Line33# < 0 THEN
  Line33# = 0#
END IF
DO
LOOP UNTIL INKEY$ <> ""
PRINT
PRINT "line 33 is:  ";
PRINT ConvertDoublePrecisionToDollars#(Line33#)
PRINT
IF CarryOver# > 0# THEN
  DO
  LOOP UNTIL INKEY$ <> ""
  PRINT
  PRINT "You could not use all of your tax credit.   The part which is not"
  PRINT "used can be carried forward to next year.  The amount which you can"
  PRINT "carry forward is:  "; CarryOver#
  PRINT
END IF

GOTO WhichRoutineNext


QuickSubtotal:
a# = TotalForLine1# - TotalForLine6#
b# = TotalForLine8# + Line10#
b# = b# - Line12#
a# = a# + Line15#
a# = a# / Line17#
a# = a# * Line19#
IF b# > a# THEN
  b# = b# - a#
ELSE
  a# = b#
  b# = 0#
END IF
a# = a# - Line32#
PRINT
PRINT "so far, your credit is:  ";
PRINT ConvertDoublePrecisionToDollars#(a#)
PRINT
IF b# > 0# THEN
  DO
  LOOP UNTIL INKEY$ <> ""
  PRINT
  PRINT "and your carry-forward is:  ";
  PRINT ConvertDoublePrecisionToDollars#(b#)
  PRINT
END IF

GOTO WhichRoutineNext

SomeonePressedEscape:
END

FUNCTION ConvertDoublePrecisionToDollars# (a#)
'This function rounds double precision numbers to two decimal places.
b# = a# * 100#
c& = b#
d# = c&
IF d# + .5# = b# THEN c& = c& + 1   'this corrects an error in Qbasic
d# = c&
ConvertDoublePrecisionToDollars# = d# / 100#
END FUNCTION

